@@ -1,4 +1,3 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/agent'
 require 'puppet/configurer'
@@ -21,16 +20,13 @@ end
 
 describe Puppet::Agent do
   before do
-    Puppet::Status.indirection.stubs(:find).returns Puppet::Status.new("version" => Puppet.version)
+    allow(Puppet::Status.indirection).to receive(:find).and_return(Puppet::Status.new("version" => Puppet.version))
 
     @agent = Puppet::Agent.new(AgentTestClient, false)
 
-    # So we don't actually try to hit the filesystem.
-    @agent.stubs(:lock).yields
-
     # make Puppet::Application safe for stubbing; restore in an :after block; silence warnings for this.
     without_warnings { Puppet::Application = Class.new(Puppet::Application) }
-    Puppet::Application.stubs(:clear?).returns(true)
+    allow(Puppet::Application).to receive(:clear?).and_return(true)
     Puppet::Application.class_eval do
       class << self
         def controlled_run(&block)
@@ -54,133 +50,132 @@ describe Puppet::Agent do
   end
 
   it "should create an instance of its client class and run it when asked to run" do
-    client = mock 'client'
-    AgentTestClient.expects(:new).returns client
+    client = double('client')
+    expect(AgentTestClient).to receive(:new).and_return(client)
 
-    client.expects(:run)
+    expect(client).to receive(:run)
 
-    @agent.stubs(:disabled?).returns false
+    allow(@agent).to receive(:disabled?).and_return(false)
     @agent.run
   end
 
   it "should initialize the client's transaction_uuid if passed as a client_option" do
-    client = mock 'client'
+    client = double('client')
     transaction_uuid = 'foo'
-    AgentTestClient.expects(:new).with(transaction_uuid, nil).returns client
+    expect(AgentTestClient).to receive(:new).with(transaction_uuid, nil).and_return(client)
 
-    client.expects(:run)
+    expect(client).to receive(:run)
 
-    @agent.stubs(:disabled?).returns false
+    allow(@agent).to receive(:disabled?).and_return(false)
     @agent.run(:transaction_uuid => transaction_uuid)
   end
 
   it "should initialize the client's job_id if passed as a client_option" do
-    client = mock 'client'
+    client = double('client')
     job_id = '289'
-    AgentTestClient.expects(:new).with(anything, job_id).returns client
+    expect(AgentTestClient).to receive(:new).with(anything, job_id).and_return(client)
 
-    client.expects(:run)
+    expect(client).to receive(:run)
 
-    @agent.stubs(:disabled?).returns false
+    allow(@agent).to receive(:disabled?).and_return(false)
     @agent.run(:job_id => job_id)
   end
 
   it "should be considered running if the lock file is locked" do
-    lockfile = mock 'lockfile'
+    lockfile = double('lockfile')
 
-    @agent.expects(:lockfile).returns(lockfile)
-    lockfile.expects(:locked?).returns true
+    expect(@agent).to receive(:lockfile).and_return(lockfile)
+    expect(lockfile).to receive(:locked?).and_return(true)
 
     expect(@agent).to be_running
   end
 
   describe "when being run" do
     before do
-      AgentTestClient.stubs(:lockfile_path).returns "/my/lock"
-      @agent.stubs(:disabled?).returns false
+      allow(AgentTestClient).to receive(:lockfile_path).and_return("/my/lock")
+      allow(@agent).to receive(:disabled?).and_return(false)
     end
 
     it "should splay" do
-      @agent.expects(:splay)
+      expect(@agent).to receive(:splay)
 
       @agent.run
     end
 
     it "should do nothing if disabled" do
-      @agent.expects(:disabled?).returns(true)
-      AgentTestClient.expects(:new).never
+      expect(@agent).to receive(:disabled?).and_return(true)
+      expect(AgentTestClient).not_to receive(:new)
       @agent.run
     end
 
     it "(#11057) should notify the user about why a run is skipped" do
-      Puppet::Application.stubs(:controlled_run).returns(false)
-      Puppet::Application.stubs(:run_status).returns('MOCK_RUN_STATUS')
+      allow(Puppet::Application).to receive(:controlled_run).and_return(false)
+      allow(Puppet::Application).to receive(:run_status).and_return('MOCK_RUN_STATUS')
       # This is the actual test that we inform the user why the run is skipped.
       # We assume this information is contained in
       # Puppet::Application.run_status
-      Puppet.expects(:notice).with(regexp_matches(/MOCK_RUN_STATUS/))
+      expect(Puppet).to receive(:notice).with(/MOCK_RUN_STATUS/)
       @agent.run
     end
 
     it "should display an informative message if the agent is administratively disabled" do
-      @agent.expects(:disabled?).returns true
-      @agent.expects(:disable_message).returns "foo"
-      Puppet.expects(:notice).with(regexp_matches(/Skipping run of .*; administratively disabled.*\(Reason: 'foo'\)/))
+      expect(@agent).to receive(:disabled?).and_return(true)
+      expect(@agent).to receive(:disable_message).and_return("foo")
+      expect(Puppet).to receive(:notice).with(/Skipping run of .*; administratively disabled.*\(Reason: 'foo'\)/)
       @agent.run
     end
 
     it "should use Puppet::Application.controlled_run to manage process state behavior" do
-      calls = sequence('calls')
-      Puppet::Application.expects(:controlled_run).yields.in_sequence(calls)
-      AgentTestClient.expects(:new).once.in_sequence(calls)
+      expect(Puppet::Application).to receive(:controlled_run).ordered.and_yield
+      expect(AgentTestClient).to receive(:new).ordered.once
       @agent.run
     end
 
     it "should not fail if a client class instance cannot be created" do
-      AgentTestClient.expects(:new).raises "eh"
-      Puppet.expects(:err)
+      expect(AgentTestClient).to receive(:new).and_raise("eh")
+      expect(Puppet).to receive(:err)
       @agent.run
     end
 
     it "should not fail if there is an exception while running its client" do
       client = AgentTestClient.new
-      AgentTestClient.expects(:new).returns client
-      client.expects(:run).raises "eh"
-      Puppet.expects(:err)
+      expect(AgentTestClient).to receive(:new).and_return(client)
+      expect(client).to receive(:run).and_raise("eh")
+      expect(Puppet).to receive(:err)
       @agent.run
     end
 
     it "should use a filesystem lock to restrict multiple processes running the agent" do
       client = AgentTestClient.new
-      AgentTestClient.expects(:new).returns client
+      expect(AgentTestClient).to receive(:new).and_return(client)
 
-      @agent.expects(:lock)
+      expect(@agent).to receive(:lock)
 
-      client.expects(:run).never # if it doesn't run, then we know our yield is what triggers it
+      expect(client).not_to receive(:run) # if it doesn't run, then we know our yield is what triggers it
       @agent.run
     end
 
     it "should make its client instance available while running" do
       client = AgentTestClient.new
-      AgentTestClient.expects(:new).returns client
+      expect(AgentTestClient).to receive(:new).and_return(client)
 
-      client.expects(:run).with { expect(@agent.client).to equal(client); true }
+      expect(client).to receive(:run) { expect(@agent.client).to equal(client); nil }
       @agent.run
     end
 
     it "should run the client instance with any arguments passed to it" do
       client = AgentTestClient.new
-      AgentTestClient.expects(:new).returns client
+      expect(AgentTestClient).to receive(:new).and_return(client)
 
-      client.expects(:run).with(:pluginsync => true, :other => :options)
+      expect(client).to receive(:run).with(:pluginsync => true, :other => :options)
       @agent.run(:other => :options)
     end
 
     it "should return the agent result" do
       client = AgentTestClient.new
-      AgentTestClient.expects(:new).returns client
+      expect(AgentTestClient).to receive(:new).and_return(client)
 
-      @agent.expects(:lock).returns(:result)
+      expect(@agent).to receive(:lock).and_return(:result)
       expect(@agent.run).to eq(:result)
     end
 
@@ -189,63 +184,63 @@ describe Puppet::Agent do
         @agent = Puppet::Agent.new(AgentTestClient, true)
 
         # So we don't actually try to hit the filesystem.
-        @agent.stubs(:lock).yields
+        allow(@agent).to receive(:lock).and_yield
 
-        Kernel.stubs(:fork)
-        Process.stubs(:waitpid2).returns [123, (stub 'process::status', :exitstatus => 0)]
-        @agent.stubs(:exit)
+        allow(Kernel).to receive(:fork)
+        allow(Process).to receive(:waitpid2).and_return([123, double('process::status', :exitstatus => 0)])
+        allow(@agent).to receive(:exit)
       end
 
       it "should run the agent in a forked process" do
         client = AgentTestClient.new
-        AgentTestClient.expects(:new).returns client
+        expect(AgentTestClient).to receive(:new).and_return(client)
 
-        client.expects(:run)
+        expect(client).to receive(:run)
 
-        Kernel.expects(:fork).yields
+        expect(Kernel).to receive(:fork).and_yield
         @agent.run
       end
 
       it "should exit child process if child exit" do
         client = AgentTestClient.new
-        AgentTestClient.expects(:new).returns client
+        expect(AgentTestClient).to receive(:new).and_return(client)
 
-        client.expects(:run).raises(SystemExit)
+        expect(client).to receive(:run).and_raise(SystemExit)
 
-        Kernel.expects(:fork).yields
-        @agent.expects(:exit).with(-1)
+        expect(Kernel).to receive(:fork).and_yield
+        expect(@agent).to receive(:exit).with(-1)
         @agent.run
       end
 
       it 'should exit with 1 if an exception is raised' do
         client = AgentTestClient.new
-        AgentTestClient.expects(:new).returns client
+        expect(AgentTestClient).to receive(:new).and_return(client)
 
-        client.expects(:run).raises(StandardError)
+        expect(client).to receive(:run).and_raise(StandardError)
 
-        Kernel.expects(:fork).yields
-        @agent.expects(:exit).with(1)
+        expect(Kernel).to receive(:fork).and_yield
+        expect(@agent).to receive(:exit).with(1)
         @agent.run
       end
 
       it "should re-raise exit happening in the child" do
-        Process.stubs(:waitpid2).returns [123, (stub 'process::status', :exitstatus => -1)]
+        allow(Process).to receive(:waitpid2).and_return([123, double('process::status', :exitstatus => -1)])
         expect { @agent.run }.to raise_error(SystemExit)
       end
 
       it "should re-raise NoMoreMemory happening in the child" do
-        Process.stubs(:waitpid2).returns [123, (stub 'process::status', :exitstatus => -2)]
+        allow(Process).to receive(:waitpid2).and_return([123, double('process::status', :exitstatus => -2)])
         expect { @agent.run }.to raise_error(NoMemoryError)
       end
 
       it "should return the child exit code" do
-        Process.stubs(:waitpid2).returns [123, (stub 'process::status', :exitstatus => 777)]
+        allow(Process).to receive(:waitpid2).and_return([123, double('process::status', :exitstatus => 777)])
         expect(@agent.run).to eq(777)
       end
 
       it "should return the block exit code as the child exit code" do
-        Kernel.expects(:fork).yields
-        @agent.expects(:exit).with(777)
+        expect(Kernel).to receive(:fork).and_yield
+        expect(@agent).to receive(:exit).with(777)
         @agent.run_in_fork {
           777
         }
@@ -282,11 +277,11 @@ describe Puppet::Agent do
           end
         end
 
-        AgentTestClient.expects(:new).returns client
+        expect(AgentTestClient).to receive(:new).and_return(client)
 
-        client.expects(:processing).never
-        client.expects(:handling).never
-        Puppet.expects(:log_exception).with(instance_of(Puppet::Agent::RunTimeoutError), anything)
+        expect(client).not_to receive(:processing)
+        expect(client).not_to receive(:handling)
+        expect(Puppet).to receive(:log_exception).with(be_an_instance_of(Puppet::Agent::RunTimeoutError), anything)
 
         expect(@agent.run).to eq(1)
       end
@@ -296,10 +291,10 @@ describe Puppet::Agent do
   describe "when checking execution state" do
     describe 'with regular run status' do
       before :each do
-        Puppet::Application.stubs(:restart_requested?).returns(false)
-        Puppet::Application.stubs(:stop_requested?).returns(false)
-        Puppet::Application.stubs(:interrupted?).returns(false)
-        Puppet::Application.stubs(:clear?).returns(true)
+        allow(Puppet::Application).to receive(:restart_requested?).and_return(false)
+        allow(Puppet::Application).to receive(:stop_requested?).and_return(false)
+        allow(Puppet::Application).to receive(:interrupted?).and_return(false)
+        allow(Puppet::Application).to receive(:clear?).and_return(true)
       end
 
       it 'should be false for :stopping?' do
@@ -313,10 +308,10 @@ describe Puppet::Agent do
 
     describe 'with a stop requested' do
       before :each do
-        Puppet::Application.stubs(:clear?).returns(false)
-        Puppet::Application.stubs(:restart_requested?).returns(false)
-        Puppet::Application.stubs(:stop_requested?).returns(true)
-        Puppet::Application.stubs(:interrupted?).returns(true)
+        allow(Puppet::Application).to receive(:clear?).and_return(false)
+        allow(Puppet::Application).to receive(:restart_requested?).and_return(false)
+        allow(Puppet::Application).to receive(:stop_requested?).and_return(true)
+        allow(Puppet::Application).to receive(:interrupted?).and_return(true)
       end
 
       it 'should be true for :stopping?' do
@@ -330,10 +325,10 @@ describe Puppet::Agent do
 
     describe 'with a restart requested' do
       before :each do
-        Puppet::Application.stubs(:clear?).returns(false)
-        Puppet::Application.stubs(:restart_requested?).returns(true)
-        Puppet::Application.stubs(:stop_requested?).returns(false)
-        Puppet::Application.stubs(:interrupted?).returns(true)
+        allow(Puppet::Application).to receive(:clear?).and_return(false)
+        allow(Puppet::Application).to receive(:restart_requested?).and_return(true)
+        allow(Puppet::Application).to receive(:stop_requested?).and_return(false)
+        allow(Puppet::Application).to receive(:interrupted?).and_return(true)
       end
 
       it 'should be false for :stopping?' do
