@@ -1,5 +1,3 @@
-#!/usr/bin/env ruby
-
 require 'spec_helper'
 
 describe Puppet::Type.type(:group).provider(:windows_adsi), :if => Puppet.features.microsoft_windows? do
@@ -11,39 +9,37 @@ describe Puppet::Type.type(:group).provider(:windows_adsi), :if => Puppet.featur
   end
 
   let(:provider) { resource.provider }
-
-  let(:connection) { stub 'connection' }
+  let(:connection) { double('connection') }
 
   before :each do
-    Puppet::Util::Windows::ADSI.stubs(:computer_name).returns('testcomputername')
-    Puppet::Util::Windows::ADSI.stubs(:connect).returns connection
+    allow(Puppet::Util::Windows::ADSI).to receive(:computer_name).and_return('testcomputername')
+    allow(Puppet::Util::Windows::ADSI).to receive(:connect).and_return(connection)
     # this would normally query the system, but not needed for these tests
-    Puppet::Util::Windows::ADSI::Group.stubs(:localized_domains).returns([])
+    allow(Puppet::Util::Windows::ADSI::Group).to receive(:localized_domains).and_return([])
   end
 
   describe ".instances" do
     it "should enumerate all groups" do
       names = ['group1', 'group2', 'group3']
-      stub_groups = names.map{|n| stub(:name => n)}
+      stub_groups = names.map{|n| double(:name => n)}
 
-      connection.stubs(:execquery).with('select name from win32_group where localaccount = "TRUE"').returns stub_groups
+      allow(connection).to receive(:execquery).with('select name from win32_group where localaccount = "TRUE"').and_return(stub_groups)
 
       expect(described_class.instances.map(&:name)).to match(names)
     end
   end
 
   describe "group type :members property helpers" do
-
-    let(:user1) { stub(:account => 'user1', :domain => '.', :sid => 'user1sid') }
-    let(:user2) { stub(:account => 'user2', :domain => '.', :sid => 'user2sid') }
-    let(:user3) { stub(:account => 'user3', :domain => '.', :sid => 'user3sid') }
+    let(:user1) { double(:account => 'user1', :domain => '.', :sid => 'user1sid') }
+    let(:user2) { double(:account => 'user2', :domain => '.', :sid => 'user2sid') }
+    let(:user3) { double(:account => 'user3', :domain => '.', :sid => 'user3sid') }
     let(:invalid_user) { SecureRandom.uuid }
 
     before :each do
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user1').returns(user1)
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user2').returns(user2)
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user3').returns(user3)
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with(invalid_user).returns(nil)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user1').and_return(user1)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user2').and_return(user2)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user3').and_return(user3)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with(invalid_user).and_return(nil)
     end
 
     describe "#members_insync?" do
@@ -212,19 +208,24 @@ describe Puppet::Type.type(:group).provider(:windows_adsi), :if => Puppet.featur
           expect(provider.members_to_s(input)).to be_empty
         end
       end
+
       it "should return an empty string on empty or nil users" do
         expect(provider.members_to_s([])).to be_empty
         expect(provider.members_to_s(nil)).to be_empty
       end
+
       it "should return a user string like DOMAIN\\USER" do
         expect(provider.members_to_s(['user1'])).to eq('.\user1')
       end
+
       it "should return a user string like DOMAIN\\USER,DOMAIN2\\USER2" do
         expect(provider.members_to_s(['user1', 'user2'])).to eq('.\user1,.\user2')
       end
+
       it "should return the username when it cannot be resolved to a SID (for the sake of resource_harness error messages)" do
         expect(provider.members_to_s([invalid_user])).to eq("#{invalid_user}")
       end
+
       it "should return the username when it cannot be resolved to a SID (for the sake of resource_harness error messages)" do
         expect(provider.members_to_s([invalid_user])).to eq("#{invalid_user}")
       end
@@ -232,44 +233,50 @@ describe Puppet::Type.type(:group).provider(:windows_adsi), :if => Puppet.featur
   end
 
   describe "when managing members" do
-    let(:user1) { stub(:account => 'user1', :domain => '.', :sid => 'user1sid') }
-    let(:user2) { stub(:account => 'user2', :domain => '.', :sid => 'user2sid') }
-    let(:user3) { stub(:account => 'user3', :domain => '.', :sid => 'user3sid') }
+    let(:user1) { double(:account => 'user1', :domain => '.', :sid => 'user1sid') }
+    let(:user2) { double(:account => 'user2', :domain => '.', :sid => 'user2sid') }
+    let(:user3) { double(:account => 'user3', :domain => '.', :sid => 'user3sid') }
 
     before :each do
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user1').returns(user1)
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user2').returns(user2)
-      Puppet::Util::Windows::SID.stubs(:name_to_principal).with('user3').returns(user3)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user1').and_return(user1)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user2').and_return(user2)
+      allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user3').and_return(user3)
 
       resource[:auth_membership] = true
     end
 
     it "should be able to provide a list of members" do
-      provider.group.stubs(:members).returns [
+      allow(provider.group).to receive(:members).and_return([
         'user1',
         'user2',
         'user3',
-      ]
+      ])
 
-      expect(provider.members).to match_array([user1.sid, user2.sid, user3.sid])
+      expected_member_sids = [user1.sid, user2.sid, user3.sid]
+      expected_members = ['user1', 'user2', 'user3']
+      allow(provider).to receive(:members_to_s)
+        .with(expected_member_sids)
+        .and_return(expected_members.join(','))
+
+      expect(provider.members).to match_array(expected_members)
     end
 
     it "should be able to set group members" do
-      provider.group.stubs(:members).returns ['user1', 'user2']
+      allow(provider.group).to receive(:members).and_return(['user1', 'user2'])
 
       member_sids = [
-        stub(:account => 'user1', :domain => 'testcomputername', :sid => 1),
-        stub(:account => 'user2', :domain => 'testcomputername', :sid => 2),
-        stub(:account => 'user3', :domain => 'testcomputername', :sid => 3),
+        double(:account => 'user1', :domain => 'testcomputername', :sid => 1),
+        double(:account => 'user2', :domain => 'testcomputername', :sid => 2),
+        double(:account => 'user3', :domain => 'testcomputername', :sid => 3),
       ]
 
-      provider.group.stubs(:member_sids).returns(member_sids[0..1])
+      allow(provider.group).to receive(:member_sids).and_return(member_sids[0..1])
 
-      Puppet::Util::Windows::SID.expects(:name_to_principal).with('user2').returns(member_sids[1])
-      Puppet::Util::Windows::SID.expects(:name_to_principal).with('user3').returns(member_sids[2])
+      expect(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user2').and_return(member_sids[1])
+      expect(Puppet::Util::Windows::SID).to receive(:name_to_principal).with('user3').and_return(member_sids[2])
 
-      provider.group.expects(:remove_member_sids).with(member_sids[0])
-      provider.group.expects(:add_member_sids).with(member_sids[2])
+      expect(provider.group).to receive(:remove_member_sids).with(member_sids[0])
+      expect(provider.group).to receive(:add_member_sids).with(member_sids[2])
 
       provider.members = ['user2', 'user3']
     end
@@ -279,69 +286,68 @@ describe Puppet::Type.type(:group).provider(:windows_adsi), :if => Puppet.featur
     it "should be able to create a group" do
       resource[:members] = ['user1', 'user2']
 
-      group = stub 'group'
-      Puppet::Util::Windows::ADSI::Group.expects(:create).with('testers').returns group
+      group = double('group')
+      expect(Puppet::Util::Windows::ADSI::Group).to receive(:create).with('testers').and_return(group)
 
-      create = sequence('create')
-      group.expects(:commit).in_sequence(create)
+      expect(group).to receive(:commit).ordered
       # due to PUP-1967, defaultto false will set the default to nil
-      group.expects(:set_members).with(['user1', 'user2'], nil).in_sequence(create)
+      expect(group).to receive(:set_members).with(['user1', 'user2'], nil).ordered
 
       provider.create
     end
 
     it 'should not create a group if a user by the same name exists' do
-      Puppet::Util::Windows::ADSI::Group.expects(:create).with('testers').raises( Puppet::Error.new("Cannot create group if user 'testers' exists.") )
+      expect(Puppet::Util::Windows::ADSI::Group).to receive(:create).with('testers').and_raise(Puppet::Error.new("Cannot create group if user 'testers' exists."))
       expect{ provider.create }.to raise_error( Puppet::Error,
         /Cannot create group if user 'testers' exists./ )
     end
 
     it "should fail with an actionable message when trying to create an active directory group" do
       resource[:name] = 'DOMAIN\testdomaingroup'
-      Puppet::Util::Windows::ADSI::User.expects(:exists?).with(resource[:name]).returns(false)
-      connection.expects(:Create)
-      connection.expects(:SetInfo).raises( WIN32OLERuntimeError.new("(in OLE method `SetInfo': )\n    OLE error code:8007089A in Active Directory\n      The specified username is invalid.\r\n\n    HRESULT error code:0x80020009\n      Exception occurred."))
+      expect(Puppet::Util::Windows::ADSI::User).to receive(:exists?).with(resource[:name]).and_return(false)
+      expect(connection).to receive(:Create)
+      expect(connection).to receive(:SetInfo).and_raise( WIN32OLERuntimeError.new("(in OLE method `SetInfo': )\n    OLE error code:8007089A in Active Directory\n      The specified username is invalid.\r\n\n    HRESULT error code:0x80020009\n      Exception occurred."))
 
       expect{ provider.create }.to raise_error(Puppet::Error)
     end
 
     it 'should commit a newly created group' do
-      provider.group.expects( :commit )
+      expect(provider.group).to receive( :commit )
 
       provider.flush
     end
   end
 
   it "should be able to test whether a group exists" do
-    Puppet::Util::Windows::SID.stubs(:name_to_principal).returns(nil)
-    Puppet::Util::Windows::ADSI.stubs(:connect).returns stub('connection', :Class => 'Group')
+    allow(Puppet::Util::Windows::SID).to receive(:name_to_principal).and_return(nil)
+    allow(Puppet::Util::Windows::ADSI).to receive(:connect).and_return(double('connection', :Class => 'Group'))
     expect(provider).to be_exists
 
-    Puppet::Util::Windows::ADSI.stubs(:connect).returns nil
+    allow(Puppet::Util::Windows::ADSI).to receive(:connect).and_return(nil)
     expect(provider).not_to be_exists
   end
 
   it "should be able to delete a group" do
-    connection.expects(:Delete).with('group', 'testers')
+    expect(connection).to receive(:Delete).with('group', 'testers')
 
     provider.delete
   end
 
   it 'should not run commit on a deleted group' do
-    connection.expects(:Delete).with('group', 'testers')
-    connection.expects(:SetInfo).never
+    expect(connection).to receive(:Delete).with('group', 'testers')
+    expect(connection).not_to receive(:SetInfo)
 
     provider.delete
     provider.flush
   end
 
   it "should report the group's SID as gid" do
-    Puppet::Util::Windows::SID.expects(:name_to_sid).with('testers').returns('S-1-5-32-547')
+    expect(Puppet::Util::Windows::SID).to receive(:name_to_sid).with('testers').and_return('S-1-5-32-547')
     expect(provider.gid).to eq('S-1-5-32-547')
   end
 
   it "should fail when trying to manage the gid property" do
-    provider.expects(:fail).with { |msg| msg =~ /gid is read-only/ }
+    expect(provider).to receive(:fail).with(/gid is read-only/)
     provider.send(:gid=, 500)
   end
 
