@@ -15,26 +15,26 @@ describe Puppet::Type.type(:package).provider(:aix) do
   end
 
   it "should uninstall a package" do
-    @provider.expects(:installp).with('-gu', 'mypackage')
-    @provider.class.expects(:pkglist).with(:pkgname => 'mypackage').returns(nil)
+    expect(@provider).to receive(:installp).with('-gu', 'mypackage')
+    expect(@provider.class).to receive(:pkglist).with(:pkgname => 'mypackage').and_return(nil)
     @provider.uninstall
   end
 
   context "when installing" do
     it "should install a package" do
-      @provider.expects(:installp).with('-acgwXY', '-d', 'mysource', 'mypackage')
+      expect(@provider).to receive(:installp).with('-acgwXY', '-d', 'mysource', 'mypackage')
       @provider.install
     end
 
     it "should install a specific package version" do
-      @resource.stubs(:should).with(:ensure).returns("1.2.3.4")
-      @provider.expects(:installp).with('-acgwXY', '-d', 'mysource', 'mypackage 1.2.3.4')
+      allow(@resource).to receive(:should).with(:ensure).and_return("1.2.3.4")
+      expect(@provider).to receive(:installp).with('-acgwXY', '-d', 'mysource', 'mypackage 1.2.3.4')
       @provider.install
     end
 
     it "should fail if the specified version is superseded" do
       @resource[:ensure] = '1.2.3.3'
-      @provider.stubs(:installp).returns <<-OUTPUT
+      allow(@provider).to receive(:installp).and_return(<<-OUTPUT)
 +-----------------------------------------------------------------------------+
                     Pre-installation Verification...
 +-----------------------------------------------------------------------------+
@@ -85,26 +85,26 @@ mypackage                 1.2.3.3         Already superseded by 1.2.3.4
 
   context "when finding the latest version" do
     it "should return the current version when no later version is present" do
-      @provider.stubs(:latest_info).returns(nil)
-      @provider.stubs(:properties).returns( { :ensure => "1.2.3.4" } )
+      allow(@provider).to receive(:latest_info).and_return(nil)
+      allow(@provider).to receive(:properties).and_return({ :ensure => "1.2.3.4" })
       expect(@provider.latest).to eq("1.2.3.4")
     end
 
     it "should return the latest version of a package" do
-      @provider.stubs(:latest_info).returns( { :version => "1.2.3.5" } )
+      allow(@provider).to receive(:latest_info).and_return({ :version => "1.2.3.5" })
       expect(@provider.latest).to eq("1.2.3.5")
     end
 
     it "should prefetch the right values" do
-      Process.stubs(:euid).returns(0)
+      allow(Process).to receive(:euid).and_return(0)
       resource = Puppet::Type.type(:package).
           new(:name => 'sudo.rte', :ensure => :latest,
               :source => 'mysource', :provider => :aix)
 
-      resource.stubs(:should).with(:ensure).returns(:latest)
+      allow(resource).to receive(:should).with(:ensure).and_return(:latest)
       resource.should(:ensure)
 
-      resource.provider.class.stubs(:execute).returns(<<-END.chomp)
+      allow(resource.provider.class).to receive(:execute).and_return(<<-END.chomp)
 sudo:sudo.rte:1.7.10.4::I:C:::::N:Configurable super-user privileges runtime::::0::
 sudo:sudo.rte:1.8.6.4::I:T:::::N:Configurable super-user privileges runtime::::0::
 END
@@ -115,15 +115,15 @@ END
   end
 
   it "update should install a package" do
-    @provider.expects(:install).with(false)
+    expect(@provider).to receive(:install).with(false)
     @provider.update
   end
 
   it "should prefetch when some packages lack sources" do
     latest = Puppet::Type.type(:package).new(:name => 'mypackage', :ensure => :latest, :source => 'mysource', :provider => :aix)
     absent = Puppet::Type.type(:package).new(:name => 'otherpackage', :ensure => :absent, :provider => :aix)
-    Process.stubs(:euid).returns(0)
-    described_class.expects(:execute).returns 'mypackage:mypackage.rte:1.8.6.4::I:T:::::N:A Super Cool Package::::0::\n'
+    allow(Process).to receive(:euid).and_return(0)
+    expect(described_class).to receive(:execute).and_return('mypackage:mypackage.rte:1.8.6.4::I:T:::::N:A Super Cool Package::::0::\n')
     described_class.prefetch({ 'mypackage' => latest, 'otherpackage' => absent })
   end
 end
