@@ -1,14 +1,23 @@
 require 'spec_helper'
 
-osfamilies = { 'windows' => ['pip.exe'], 'other' => ['pip', 'pip-python'] }
+osfamilies = { 'windows' => ['pip.exe'], 'other' => ['pip', 'pip-python', 'pip2', 'pip-2'] }
 
 describe Puppet::Type.type(:package).provider(:pip) do
-  before do  
+
+  it { is_expected.to be_installable }
+  it { is_expected.to be_uninstallable }
+  it { is_expected.to be_upgradeable }
+  it { is_expected.to be_versionable }
+  it { is_expected.to be_install_options }
+  it { is_expected.to be_targetable }
+
+  before do
     @resource = Puppet::Resource.new(:package, "fake_package")
+    allow(@resource).to receive(:original_parameters).and_return({})
     @provider = described_class.new(@resource)
-    @client = stub_everything('client')
-    @client.stubs(:call).with('package_releases', 'real_package').returns(["1.3", "1.2.5", "1.2.4"])
-    @client.stubs(:call).with('package_releases', 'fake_package').returns([])
+    @client = double('client')
+    allow(@client).to receive(:call).with('package_releases', 'real_package').and_return(["1.3", "1.2.5", "1.2.4"])
+    allow(@client).to receive(:call).with('package_releases', 'fake_package').and_return([])
   end
 
   context "parse" do
@@ -27,17 +36,17 @@ describe Puppet::Type.type(:package).provider(:pip) do
 
   context "cmd" do
     it "should return 'pip.exe' by default on Windows systems" do
-      Puppet.features.stubs(:microsoft_windows?).returns true
+      allow(Puppet.features).to receive(:microsoft_windows?).and_return(true)
       expect(described_class.cmd[0]).to eq('pip.exe')
     end
 
     it "could return pip-python on legacy redhat systems which rename pip" do
-      Puppet.features.stubs(:microsoft_windows?).returns false
+      allow(Puppet.features).to receive(:microsoft_windows?).and_return(false)
       expect(described_class.cmd[1]).to eq('pip-python')
     end
 
     it "should return pip by default on other systems" do
-      Puppet.features.stubs(:microsoft_windows?).returns false
+      allow(Puppet.features).to receive(:microsoft_windows?).and_return(false)
       expect(described_class.cmd[0]).to eq('pip')
     end
   end
@@ -45,18 +54,18 @@ describe Puppet::Type.type(:package).provider(:pip) do
   context "instances" do
     osfamilies.each do |osfamily, pip_cmds|
       it "should return an array on #{osfamily} systems when #{pip_cmds.join(' or ')} is present" do
-        Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
-        pip_cmds.each do |pip_cmd|  
+        allow(Puppet.features).to receive(:microsoft_windows?).and_return(osfamily == 'windows')
+        pip_cmds.each do |pip_cmd|
           pip_cmds.each do |cmd|
             unless cmd == pip_cmd
-              described_class.expects(:which).with(cmd).returns(nil)
+              expect(described_class).to receive(:which).with(cmd).and_return(nil)
             end
           end
-          described_class.stubs(:pip_version).returns('8.0.1')
-          described_class.expects(:which).with(pip_cmd).returns("/fake/bin/#{pip_cmd}")
-          p = stub("process")
-          p.expects(:collect).yields("real_package==1.2.5")
-          described_class.expects(:execpipe).with(["/fake/bin/#{pip_cmd}", "freeze"]).yields(p)
+          allow(described_class).to receive(:pip_version).with(pip_cmd).and_return('8.0.1')
+          expect(described_class).to receive(:which).with(pip_cmd).and_return(pip_cmd)
+          p = double("process")
+          expect(p).to receive(:collect).and_yield("real_package==1.2.5")
+          expect(described_class).to receive(:execpipe).with([pip_cmd, ["freeze"]]).and_yield(p)
           described_class.instances
         end
       end
@@ -65,21 +74,21 @@ describe Puppet::Type.type(:package).provider(:pip) do
         versions = ['8.1.0', '9.0.1']
         versions.each do |version|
           it "should use the --all option when version is '#{version}'" do
-            Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
-            described_class.stubs(:pip_cmd).returns('/fake/bin/pip')
-            described_class.stubs(:pip_version).returns(version)
-            p = stub("process")
-            p.expects(:collect).yields("real_package==1.2.5")
-            described_class.expects(:execpipe).with(["/fake/bin/pip", "freeze", "--all"]).yields(p)
+            allow(Puppet.features).to receive(:microsoft_windows?).and_return(osfamily == 'windows')
+            allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+            allow(described_class).to receive(:pip_version).with('/fake/bin/pip').and_return(version)
+            p = double("process")
+            expect(p).to receive(:collect).and_yield("real_package==1.2.5")
+            expect(described_class).to receive(:execpipe).with(["/fake/bin/pip", ["freeze", "--all"]]).and_yield(p)
             described_class.instances
           end
         end
       end
 
       it "should return an empty array on #{osfamily} systems when #{pip_cmds.join(' and ')} are missing" do
-        Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
+        allow(Puppet.features).to receive(:microsoft_windows?).and_return(osfamily == 'windows')
         pip_cmds.each do |cmd|
-          described_class.expects(:which).with(cmd).returns nil
+          expect(described_class).to receive(:which).with(cmd).and_return(nil)
         end
         expect(described_class.instances).to eq([])
       end
@@ -89,40 +98,46 @@ describe Puppet::Type.type(:package).provider(:pip) do
   context "query" do
     before do
       @resource[:name] = "real_package"
+      allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+      allow(described_class).to receive(:validate_command).with('/fake/bin/pip')
     end
 
     it "should return a hash when pip and the package are present" do
-      described_class.expects(:instances).returns [described_class.new({
+      expect(described_class).to receive(:instances).and_return([described_class.new({
         :ensure   => "1.2.5",
         :name     => "real_package",
         :provider => :pip,
-      })]
+        :command  => '/fake/bin/pip',
+      })])
 
       expect(@provider.query).to eq({
         :ensure   => "1.2.5",
         :name     => "real_package",
         :provider => :pip,
+        :command  => '/fake/bin/pip',
       })
     end
 
     it "should return nil when the package is missing" do
-      described_class.expects(:instances).returns []
+      expect(described_class).to receive(:instances).and_return([])
       expect(@provider.query).to eq(nil)
     end
 
     it "should be case insensitive" do
       @resource[:name] = "Real_Package"
 
-      described_class.expects(:instances).returns [described_class.new({
+      expect(described_class).to receive(:instances).and_return([described_class.new({
         :ensure   => "1.2.5",
         :name     => "real_package",
         :provider => :pip,
-      })]
+        :command  => '/fake/bin/pip',
+      })])
 
       expect(@provider.query).to eq({
         :ensure   => "1.2.5",
         :name     => "real_package",
         :provider => :pip,
+        :command  => '/fake/bin/pip',
       })
     end
   end
@@ -130,10 +145,12 @@ describe Puppet::Type.type(:package).provider(:pip) do
   context "latest" do
     context "with pip version < 1.5.4" do
       before :each do
-        described_class.stubs(:pip_version).returns('1.0.1')
-        described_class.stubs(:which).with('pip').returns("/fake/bin/pip")
-        described_class.stubs(:which).with('pip-python').returns("/fake/bin/pip")
-        described_class.stubs(:which).with('pip.exe').returns("/fake/bin/pip")
+        allow(described_class).to receive(:pip_version).with("/fake/bin/pip").and_return('1.0.1')
+        allow(described_class).to receive(:which).with('pip').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:which).with('pip-python').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:which).with('pip.exe').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+        allow(described_class).to receive(:validate_command).with('/fake/bin/pip')
       end
 
       it "should find a version number for new_pip_package" do
@@ -146,7 +163,7 @@ describe Puppet::Type.type(:package).provider(:pip) do
           Successfully downloaded real-package
           EOS
         )
-        Puppet::Util::Execution.expects(:execpipe).yields(p).once
+        expect(Puppet::Util::Execution).to receive(:execpipe).and_yield(p).once
         @resource[:name] = "real_package"
         expect(@provider.latest).to eq('0.10.1')
       end
@@ -176,20 +193,29 @@ describe Puppet::Type.type(:package).provider(:pip) do
           Storing complete log in /root/.pip/pip.log
           EOS
         )
-        Puppet::Util::Execution.expects(:execpipe).yields(p).once
+        expect(Puppet::Util::Execution).to receive(:execpipe).and_yield(p).once
         @resource[:name] = "fake_package"
         expect(@provider.latest).to eq(nil)
       end
+
+      it "should use 'install_options' when specified" do
+        expect(Puppet::Util::Execution).to receive(:execpipe).with(array_including([["--index=https://fake.example.com"]])).once
+        @resource[:name] = "fake_package"
+        @resource[:install_options] = ['--index' => 'https://fake.example.com']
+        expect(@provider.latest).to eq(nil)
+      end
     end
 
     context "with pip version >= 1.5.4" do
       # For Pip 1.5.4 and above, you can get a version list from CLI - which allows for native pip behavior
       # with regards to custom repositories, proxies and the like
       before :each do
-        described_class.stubs(:pip_version).returns('1.5.4')
-        described_class.stubs(:which).with('pip').returns("/fake/bin/pip")
-        described_class.stubs(:which).with('pip-python').returns("/fake/bin/pip")
-        described_class.stubs(:which).with('pip.exe').returns("/fake/bin/pip")
+        allow(described_class).to receive(:pip_version).with("/fake/bin/pip").and_return('1.5.4')
+        allow(described_class).to receive(:which).with('pip').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:which).with('pip-python').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:which).with('pip.exe').and_return("/fake/bin/pip")
+        allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+        allow(described_class).to receive(:validate_command).with('/fake/bin/pip')
       end
 
       it "should find a version number for real_package" do
@@ -200,7 +226,7 @@ describe Puppet::Type.type(:package).provider(:pip) do
           No matching distribution found for real-package==versionplease
           EOS
         )
-        Puppet::Util::Execution.expects(:execpipe).with(["/fake/bin/pip", "install", "real_package==versionplease"]).yields(p).once
+        expect(Puppet::Util::Execution).to receive(:execpipe).with(["/fake/bin/pip", "install", "real_package==versionplease"]).and_yield(p).once
         @resource[:name] = "real_package"
         latest = @provider.latest
         expect(latest).to eq('1.9b1')
@@ -214,7 +240,7 @@ describe Puppet::Type.type(:package).provider(:pip) do
           No matching distribution found for fake-package==versionplease
           EOS
         )
-        Puppet::Util::Execution.expects(:execpipe).with(["/fake/bin/pip", "install", "fake_package==versionplease"]).yields(p).once
+        expect(Puppet::Util::Execution).to receive(:execpipe).with(["/fake/bin/pip", "install", "fake_package==versionplease"]).and_yield(p).once
         @resource[:name] = "fake_package"
         expect(@provider.latest).to eq(nil)
       end
@@ -227,11 +253,18 @@ describe Puppet::Type.type(:package).provider(:pip) do
           No distributions matching the version for real-package==versionplease
           EOS
         )
-        Puppet::Util::Execution.expects(:execpipe).with(["/fake/bin/pip", "install", "real_package==versionplease"]).yields(p).once
+        expect(Puppet::Util::Execution).to receive(:execpipe).with(["/fake/bin/pip", "install", "real_package==versionplease"]).and_yield(p).once
         @resource[:name] = "real_package"
         latest = @provider.latest
         expect(latest).to eq('15.0.2')
       end
+
+      it "should use 'install_options' when specified" do
+        expect(Puppet::Util::Execution).to receive(:execpipe).with(array_including([["--index=https://fake.example.com"]])).once
+        @resource[:name] = "fake_package"
+        @resource[:install_options] = ['--index' => 'https://fake.example.com']
+        expect(@provider.latest).to eq(nil)
+      end
     end
   end
 
@@ -239,13 +272,14 @@ describe Puppet::Type.type(:package).provider(:pip) do
     before do
       @resource[:name] = "fake_package"
       @url = "git+https://example.com/fake_package.git"
+      allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+      allow(described_class).to receive(:validate_command).with('/fake/bin/pip')
     end
 
     it "should install" do
       @resource[:ensure] = :installed
       @resource[:source] = nil
-      @provider.expects(:lazy_pip).
-        with("install", '-q', "fake_package")
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "fake_package"]])
       @provider.install
     end
 
@@ -253,8 +287,9 @@ describe Puppet::Type.type(:package).provider(:pip) do
       # The -e flag makes the provider non-idempotent
       @resource[:ensure] = :installed
       @resource[:source] = @url
-      @provider.expects(:lazy_pip).with() do |*args|
-        not args.include?("-e")
+      # TJK
+      expect(@provider).to receive(:execute) do |*args|
+        expect(args).not_to include("-e")
       end
       @provider.install
     end
@@ -262,31 +297,31 @@ describe Puppet::Type.type(:package).provider(:pip) do
     it "should install from SCM" do
       @resource[:ensure] = :installed
       @resource[:source] = @url
-      @provider.expects(:lazy_pip).
-        with("install", '-q', "#{@url}#egg=fake_package")
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "#{@url}#egg=fake_package"]])
       @provider.install
     end
 
     it "should install a particular SCM revision" do
       @resource[:ensure] = "0123456"
       @resource[:source] = @url
-      @provider.expects(:lazy_pip).
-        with("install", "-q", "#{@url}@0123456#egg=fake_package")
+      # TJK
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "#{@url}@0123456#egg=fake_package"]])
       @provider.install
     end
 
     it "should install a particular version" do
       @resource[:ensure] = "0.0.0"
       @resource[:source] = nil
-      @provider.expects(:lazy_pip).with("install", "-q", "fake_package==0.0.0")
+      # TJK
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "fake_package==0.0.0"]])
       @provider.install
     end
 
     it "should upgrade" do
       @resource[:ensure] = :latest
       @resource[:source] = nil
-      @provider.expects(:lazy_pip).
-        with("install", "-q", "--upgrade", "fake_package")
+      # TJK
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "--upgrade", "fake_package"]])
       @provider.install
     end
 
@@ -294,86 +329,85 @@ describe Puppet::Type.type(:package).provider(:pip) do
       @resource[:ensure] = :installed
       @resource[:source] = nil
       @resource[:install_options] = [{"--timeout" => "10"}, "--no-index"]
-      @provider.expects(:lazy_pip).
-        with("install", "-q", "--timeout=10", "--no-index", "fake_package")
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["install", "-q", "--timeout=10", "--no-index", "fake_package"]])
       @provider.install
     end
   end
 
   context "uninstall" do
+    before do
+      allow(described_class).to receive(:provider_command).and_return('/fake/bin/pip')
+      allow(described_class).to receive(:validate_command).with('/fake/bin/pip')
+    end
+
     it "should uninstall" do
       @resource[:name] = "fake_package"
-      @provider.expects(:lazy_pip).
-        with('uninstall', '-y', '-q', 'fake_package')
+      expect(@provider).to receive(:execute).with(["/fake/bin/pip", ["uninstall", "-y", "-q", "fake_package"]])
       @provider.uninstall
     end
   end
 
   context "update" do
     it "should just call install" do
-      @provider.expects(:install).returns(nil)
+      expect(@provider).to receive(:install).and_return(nil)
       @provider.update
     end
   end
 
   context "pip_version" do
-    it "should return nil on missing pip" do
-      described_class.stubs(:pip_cmd).returns(nil)
-      expect(described_class.pip_version).to eq(nil)
-    end
+    let(:pip) { '/fake/bin/pip' }
 
     it "should look up version if pip is present" do
-      described_class.stubs(:pip_cmd).returns('/fake/bin/pip')
-      p = stub("process")
-      p.expects(:collect).yields('pip 8.0.2 from /usr/local/lib/python2.7/dist-packages (python 2.7)')
-      described_class.expects(:execpipe).with(['/fake/bin/pip', '--version']).yields(p)
-      expect(described_class.pip_version).to eq('8.0.2')
+      allow(described_class).to receive(:pip_cmd).and_return(pip)
+      process = ['pip 8.0.2 from /usr/local/lib/python2.7/dist-packages (python 2.7)']
+      allow(described_class).to receive(:execpipe).with([pip, '--version']).and_yield(process)
+
+      expect(described_class.pip_version(pip)).to eq('8.0.2')
+    end
+
+    it "parses multiple lines of output" do
+      allow(described_class).to receive(:pip_cmd).and_return(pip)
+      process = [
+        "/usr/local/lib/python2.7/dist-packages/urllib3/contrib/socks.py:37: DependencyWarning: SOCKS support in urllib3 requires the installation of optional dependencies: specifically, PySocks. For more information, see https://urllib3.readthedocs.io/en/latest/contrib.html#socks-proxies",
+        "  DependencyWarning",
+        "pip 1.5.6 from /usr/lib/python2.7/dist-packages (python 2.7)"
+      ]
+      allow(described_class).to receive(:execpipe).with([pip, '--version']).and_yield(process)
+
+      expect(described_class.pip_version(pip)).to eq('1.5.6')
+    end
+
+    it "raises if there isn't a version string" do
+      allow(described_class).to receive(:pip_cmd).and_return(pip)
+      allow(described_class).to receive(:execpipe).with([pip, '--version']).and_yield([""])
+      expect {
+        described_class.pip_version(pip)
+      }.to raise_error(Puppet::Error, 'Cannot resolve pip version')
+    end
+
+    it "quotes commands with spaces" do
+      pip = 'C:\Program Files\Python27\Scripts\pip.exe'
+      allow(described_class).to receive(:pip_cmd).and_return(pip)
+      process = ["pip 18.1 from c:\program files\python27\lib\site-packages\pip (python 2.7)\r\n"]
+      allow(described_class).to receive(:execpipe).with(["\"#{pip}\"", '--version']).and_yield(process)
+
+      expect(described_class.pip_version(pip)).to eq('18.1')
     end
   end
 
-  context "lazy_pip" do
-    after(:each) do
-      Puppet::Type::Package::ProviderPip.instance_variable_set(:@confine_collection, nil)
+  context 'calculated specificity' do
+    context 'when is not defaultfor' do
+      subject { described_class.specificity }
+      it { is_expected.to eql 1 }
     end
 
-    it "should succeed if pip is present" do
-      @provider.stubs(:pip).returns(nil)
-      @provider.method(:lazy_pip).call "freeze"
-    end
-
-    osfamilies.each do |osfamily, pip_cmds|
-      pip_cmds.each do |pip_cmd|
-        it "should retry on #{osfamily} systems if #{pip_cmd} has not yet been found" do
-          Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
-          @provider.expects(:pip).twice.with('freeze').raises(NoMethodError).then.returns(nil)
-          pip_cmds.each do |cmd|
-            unless cmd == pip_cmd
-              @provider.expects(:which).with(cmd).returns(nil)
-            end
-          end
-          @provider.expects(:which).with(pip_cmd).returns("/fake/bin/#{pip_cmd}")
-          @provider.method(:lazy_pip).call "freeze"
-        end
-      end
-
-      it "should fail on #{osfamily} systems if #{pip_cmds.join(' and ')} are missing" do
-        Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
-        @provider.expects(:pip).with('freeze').raises(NoMethodError)
-        pip_cmds.each do |pip_cmd|
-          @provider.expects(:which).with(pip_cmd).returns(nil)
-        end
-        expect { @provider.method(:lazy_pip).call("freeze") }.to raise_error(NoMethodError)
-      end
-
-      it "should output a useful error message on #{osfamily} systems if #{pip_cmds.join(' and ')} are missing" do
-        Puppet.features.stubs(:microsoft_windows?).returns (osfamily == 'windows')
-        @provider.expects(:pip).with('freeze').raises(NoMethodError)
-        pip_cmds.each do |pip_cmd|
-          @provider.expects(:which).with(pip_cmd).returns(nil)
-        end
-        expect { @provider.method(:lazy_pip).call("freeze") }.
-          to raise_error(NoMethodError, "Could not locate command #{pip_cmds.join(' and ')}.")
+    context 'when is defaultfor' do
+      let(:os) {  Facter.value(:operatingsystem) }
+      subject do
+        described_class.defaultfor(operatingsystem: os)
+        described_class.specificity
       end
+      it { is_expected.to be > 100 }
     end
   end
 end
