@@ -1,13 +1,11 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
 describe Puppet::Type.type(:user).provider(:openbsd) do
-
   before :each do
-    described_class.stubs(:command).with(:password).returns '/usr/sbin/passwd'
-    described_class.stubs(:command).with(:add).returns '/usr/sbin/useradd'
-    described_class.stubs(:command).with(:modify).returns '/usr/sbin/usermod'
-    described_class.stubs(:command).with(:delete).returns '/usr/sbin/userdel'
+    allow(described_class).to receive(:command).with(:password).and_return('/usr/sbin/passwd')
+    allow(described_class).to receive(:command).with(:add).and_return('/usr/sbin/useradd')
+    allow(described_class).to receive(:command).with(:modify).and_return('/usr/sbin/usermod')
+    allow(described_class).to receive(:command).with(:delete).and_return('/usr/sbin/userdel')
   end
 
   let(:resource) do
@@ -33,20 +31,20 @@ describe Puppet::Type.type(:user).provider(:openbsd) do
   describe "#expiry=" do
     it "should pass expiry to usermod as MM/DD/YY" do
       resource[:expiry] = '2014-11-05'
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-e', 'November 05 2014', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-e', 'November 05 2014', 'myuser'], hash_including(custom_environment: {}))
       provider.expiry = '2014-11-05'
     end
 
     it "should use -e with an empty string when the expiry property is removed" do
       resource[:expiry] = :absent
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-e', '', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-e', '', 'myuser'], hash_including(custom_environment: {}))
       provider.expiry = :absent
     end
   end
 
   describe "#addcmd" do
     it "should return an array with the full command and expiry as MM/DD/YY" do
-      Facter.stubs(:value).with(:osfamily).returns('OpenBSD')
+      allow(Facter).to receive(:value).with(:osfamily).and_return('OpenBSD')
       resource[:expiry] = "1997-06-01"
       expect(provider.addcmd).to eq(['/usr/sbin/useradd', '-e', 'June 01 1997', 'myuser'])
     end
@@ -58,19 +56,19 @@ describe Puppet::Type.type(:user).provider(:openbsd) do
     end
 
     it "should return the loginclass if set", :if => Puppet.features.libshadow? do
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
       provider.send(:loginclass).should == 'staff'
     end
 
     it "should return the empty string when loginclass isn't set", :if => Puppet.features.libshadow? do
       shadow_entry[:sp_loginclass] = ''
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
       provider.send(:loginclass).should == ''
     end
 
     it "should return nil when loginclass isn't available", :if => Puppet.features.libshadow? do
       shadow_entry[:sp_loginclass] = nil
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
       provider.send(:loginclass).should be_nil
     end
   end
