@@ -1,17 +1,17 @@
-#! /usr/bin/env ruby
 require 'spec_helper'
 
-describe Puppet::Type.type(:user).provider(:useradd) do
+RSpec::Matchers.define_negated_matcher :excluding, :include
 
+describe Puppet::Type.type(:user).provider(:useradd) do
   before :each do
-    described_class.stubs(:command).with(:password).returns '/usr/bin/chage'
-    described_class.stubs(:command).with(:localpassword).returns '/usr/sbin/lchage'
-    described_class.stubs(:command).with(:add).returns '/usr/sbin/useradd'
-    described_class.stubs(:command).with(:localadd).returns '/usr/sbin/luseradd'
-    described_class.stubs(:command).with(:modify).returns '/usr/sbin/usermod'
-    described_class.stubs(:command).with(:localmodify).returns '/usr/sbin/lusermod'
-    described_class.stubs(:command).with(:delete).returns '/usr/sbin/userdel'
-    described_class.stubs(:command).with(:localdelete).returns '/usr/sbin/luserdel'
+    allow(described_class).to receive(:command).with(:password).and_return('/usr/bin/chage')
+    allow(described_class).to receive(:command).with(:localpassword).and_return('/usr/sbin/lchage')
+    allow(described_class).to receive(:command).with(:add).and_return('/usr/sbin/useradd')
+    allow(described_class).to receive(:command).with(:localadd).and_return('/usr/sbin/luseradd')
+    allow(described_class).to receive(:command).with(:modify).and_return('/usr/sbin/usermod')
+    allow(described_class).to receive(:command).with(:localmodify).and_return('/usr/sbin/lusermod')
+    allow(described_class).to receive(:command).with(:delete).and_return('/usr/sbin/userdel')
+    allow(described_class).to receive(:command).with(:localdelete).and_return('/usr/sbin/luserdel')
   end
 
   let(:resource) do
@@ -25,7 +25,6 @@ describe Puppet::Type.type(:user).provider(:useradd) do
 
   let(:provider) { described_class.new(:name => 'myuser') }
 
-
   let(:shadow_entry) {
     return unless Puppet.features.libshadow?
     entry = Struct::PasswdEntry.new
@@ -41,37 +40,57 @@ describe Puppet::Type.type(:user).provider(:useradd) do
   }
 
   describe "#create" do
-
     before do
-      provider.stubs(:exists?).returns(false)
+      allow(provider).to receive(:exists?).and_return(false)
+    end
+
+    it "should not redact the command from debug logs if there is no password" do
+      described_class.has_feature :manages_passwords
+      resource[:ensure] = :present
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: false))
+      provider.create
+    end
+
+    it "should redact the command from debug logs if there is a password" do
+      described_class.has_feature :manages_passwords
+      resource2 = Puppet::Type.type(:user).new(
+        :name       => 'myuser',
+        :password   => 'a pass word',
+        :managehome => :false,
+        :system     => :false,
+        :provider   => provider,
+      )
+      resource2[:ensure] = :present
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: true))
+      provider.create
     end
 
     it "should add -g when no gid is specified and group already exists" do
-      Puppet::Util.stubs(:gid).returns(true)
+      allow(Puppet::Util).to receive(:gid).and_return(true)
       resource[:ensure] = :present
-      provider.expects(:execute).with(includes('-g'), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include('-g'), kind_of(Hash))
       provider.create
     end
 
     it "should use -G to set groups" do
-      Facter.stubs(:value).with(:osfamily).returns('Not RedHat')
+      allow(Facter).to receive(:value).with(:osfamily).and_return('Not RedHat')
       resource[:ensure] = :present
       resource[:groups] = ['group1', 'group2']
-      provider.expects(:execute).with(['/usr/sbin/useradd', '-G', 'group1,group2', 'myuser'], kind_of(Hash))
+      expect(provider).to receive(:execute).with(['/usr/sbin/useradd', '-G', 'group1,group2', 'myuser'], kind_of(Hash))
       provider.create
     end
 
     it "should use -G to set groups without -M on RedHat" do
-      Facter.stubs(:value).with(:osfamily).returns('RedHat')
+      allow(Facter).to receive(:value).with(:osfamily).and_return('RedHat')
       resource[:ensure] = :present
       resource[:groups] = ['group1', 'group2']
-      provider.expects(:execute).with(['/usr/sbin/useradd', '-G', 'group1,group2', '-M', 'myuser'], kind_of(Hash))
+      expect(provider).to receive(:execute).with(['/usr/sbin/useradd', '-G', 'group1,group2', '-M', 'myuser'], kind_of(Hash))
       provider.create
     end
 
     it "should add -o when allowdupe is enabled and the user is being created" do
       resource[:allowdupe] = true
-      provider.expects(:execute).with(includes('-o'), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include('-o'), kind_of(Hash))
       provider.create
     end
 
@@ -79,7 +98,7 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       it "should add -r when system is enabled" do
         resource[:system] = :true
         expect(provider).to be_system_users
-        provider.expects(:execute).with(includes('-r'), kind_of(Hash))
+        expect(provider).to receive(:execute).with(include('-r'), kind_of(Hash))
         provider.create
       end
     end
@@ -88,7 +107,7 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       it "should not add -r when system is enabled" do
         resource[:system] = :true
         expect(provider).not_to be_system_users
-        provider.expects(:execute).with(['/usr/sbin/useradd', 'myuser'], kind_of(Hash))
+        expect(provider).to receive(:execute).with(['/usr/sbin/useradd', 'myuser'], kind_of(Hash))
         provider.create
       end
     end
@@ -98,8 +117,8 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       resource[:password_min_age] = 5
       resource[:password_max_age] = 10
       resource[:password_warn_days] = 15
-      provider.expects(:execute).with(includes('/usr/sbin/useradd'), kind_of(Hash))
-      provider.expects(:execute).with(['/usr/bin/chage', '-m', 5, '-M', 10, '-W', 15, 'myuser'], has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+      expect(provider).to receive(:execute).with(include('/usr/sbin/useradd'), kind_of(Hash))
+      expect(provider).to receive(:execute).with(['/usr/bin/chage', '-m', 5, '-M', 10, '-W', 15, 'myuser'], hash_including(failonfail: true, combine: true, custom_environment: {}))
       provider.create
     end
 
@@ -108,40 +127,41 @@ describe Puppet::Type.type(:user).provider(:useradd) do
          described_class.has_feature :libuser
          resource[:forcelocal] = true
       end
+
       it "should use luseradd instead of useradd" do
-        provider.expects(:execute).with(includes('/usr/sbin/luseradd'), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/luseradd'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
 
       it "should NOT use -o when allowdupe=true" do
         resource[:allowdupe] = :true
-        provider.expects(:execute).with(Not(includes('-o')), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(excluding('-o'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
 
       it "should raise an exception for duplicate UIDs" do
         resource[:uid] = 505
-        provider.stubs(:finduser).returns(true)
+        allow(provider).to receive(:finduser).and_return(true)
         expect { provider.create }.to raise_error(Puppet::Error, "UID 505 already exists, use allowdupe to force user creation")
       end
 
       it "should not use -G for luseradd and should call usermod with -G after luseradd when groups property is set" do
         resource[:groups] = ['group1', 'group2']
-        provider.expects(:execute).with(all_of(includes('/usr/sbin/luseradd'), Not(includes('-G'))), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
-        provider.expects(:execute).with(all_of(includes('/usr/sbin/usermod'), includes('-G')), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/luseradd').and(excluding('-G')), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/usermod').and(include('-G')), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
 
       it "should not use -m when managehome set" do
         resource[:managehome] = :true
-        provider.expects(:execute).with(Not(includes('-m')), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(excluding('-m'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
 
       it "should not use -e with luseradd, should call usermod with -e after luseradd when expiry is set" do
         resource[:expiry] = '2038-01-24'
-        provider.expects(:execute).with(all_of(includes('/usr/sbin/luseradd'), Not(includes('-e'))), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
-        provider.expects(:execute).with(all_of(includes('/usr/sbin/usermod'), includes('-e')), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/luseradd').and(excluding('-e')), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/usermod').and(include('-e')), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
 
@@ -150,8 +170,8 @@ describe Puppet::Type.type(:user).provider(:useradd) do
         resource[:password_min_age] = 5
         resource[:password_max_age] = 10
         resource[:password_warn_days] = 15
-        provider.expects(:execute).with(includes('/usr/sbin/luseradd'), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
-        provider.expects(:execute).with(['/usr/sbin/lchage', '-m', 5, '-M', 10, '-W', 15, 'myuser'], has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/luseradd'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(['/usr/sbin/lchage', '-m', 5, '-M', 10, '-W', 15, 'myuser'], hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.create
       end
     end
@@ -159,12 +179,32 @@ describe Puppet::Type.type(:user).provider(:useradd) do
     describe "on systems that allow to set shell" do
       it "should trigger shell validation" do
         resource[:shell] = '/bin/bash'
-        provider.expects(:check_valid_shell)
-        provider.expects(:execute).with(includes('-s'), kind_of(Hash))
+        expect(provider).to receive(:check_valid_shell)
+        expect(provider).to receive(:execute).with(include('-s'), kind_of(Hash))
         provider.create
       end
     end
+  end
 
+  describe 'when modifying the password' do
+    before do
+      described_class.has_feature :libuser
+      described_class.has_feature :manages_passwords
+      #Setting any resource value here initializes needed variables and methods in the resource and provider
+      #Setting a password value here initializes the existence and management of the password parameter itself
+      #Otherwise, this value would not need to be initialized for the test
+      resource[:password] = ''
+    end
+
+    it "should not call execute with sensitive if non-sensitive data is changed" do
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: false))
+      provider.home = 'foo/bar'
+    end
+
+    it "should call execute with sensitive if sensitive data is changed" do
+      expect(provider).to receive(:execute).with(kind_of(Array), hash_including(sensitive: true))
+      provider.password = 'bird bird bird'
+    end
   end
 
   describe '#modify' do
@@ -175,34 +215,34 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       end
 
       it "should use usermod" do
-        provider.expects(:execute).with(['/usr/sbin/usermod', '-u', 150, 'myuser'], has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+        expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-u', 150, 'myuser'], hash_including(failonfail: true, combine: true, custom_environment: {}))
         provider.uid = 150
       end
 
       it "should use -o when allowdupe=true" do
         resource[:allowdupe] = :true
-        provider.expects(:execute).with(includes('-o'), has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+        expect(provider).to receive(:execute).with(include('-o'), hash_including(failonfail: true, combine: true, custom_environment: {}))
         provider.uid = 505
       end
 
       it 'should use chage for password_min_age' do
-        provider.expects(:execute).with(['/usr/bin/chage', '-m', 100, 'myuser'], has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+        expect(provider).to receive(:execute).with(['/usr/bin/chage', '-m', 100, 'myuser'], hash_including(failonfail: true, combine: true, custom_environment: {}))
         provider.password_min_age = 100
       end
 
       it 'should use chage for password_max_age' do
-        provider.expects(:execute).with(['/usr/bin/chage', '-M', 101, 'myuser'], has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+        expect(provider).to receive(:execute).with(['/usr/bin/chage', '-M', 101, 'myuser'], hash_including(failonfail: true, combine: true, custom_environment: {}))
         provider.password_max_age = 101
       end
 
       it 'should use chage for password_warn_days' do
-        provider.expects(:execute).with(['/usr/bin/chage', '-W', 99, 'myuser'], has_entries({:failonfail => true, :combine => true, :custom_environment => {}}))
+        expect(provider).to receive(:execute).with(['/usr/bin/chage', '-W', 99, 'myuser'], hash_including(failonfail: true, combine: true, custom_environment: {}))
         provider.password_warn_days = 99
       end
 
       it 'should not call check_allow_dup if not modifying the uid' do
-        provider.expects(:check_allow_dup).never
-        provider.expects(:execute)
+        expect(provider).not_to receive(:check_allow_dup)
+        expect(provider).to receive(:execute)
         provider.home = 'foo/bar'
       end
     end
@@ -214,34 +254,34 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       end
 
       it "should use lusermod and not usermod" do
-        provider.expects(:execute).with(['/usr/sbin/lusermod', '-u', 150, 'myuser'], has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(['/usr/sbin/lusermod', '-u', 150, 'myuser'], hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.uid = 150
       end
 
       it "should NOT use -o when allowdupe=true" do
         resource[:allowdupe] = :true
-        provider.expects(:execute).with(Not(includes('-o')), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(excluding('-o'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.uid = 505
       end
 
       it "should raise an exception for duplicate UIDs" do
         resource[:uid] = 505
-        provider.stubs(:finduser).returns(true)
+        allow(provider).to receive(:finduser).and_return(true)
         expect { provider.uid = 505 }.to raise_error(Puppet::Error, "UID 505 already exists, use allowdupe to force user creation")
       end
 
       it 'should use lchage for password_warn_days' do
-        provider.expects(:execute).with(['/usr/sbin/lchage', '-W', 99, 'myuser'], has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(['/usr/sbin/lchage', '-W', 99, 'myuser'], hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.password_warn_days = 99
       end
 
       it 'should use lchage for password_min_age' do
-        provider.expects(:execute).with(['/usr/sbin/lchage', '-m', 100, 'myuser'], has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(['/usr/sbin/lchage', '-m', 100, 'myuser'], hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.password_min_age = 100
       end
 
       it 'should use lchage for password_max_age' do
-        provider.expects(:execute).with(['/usr/sbin/lchage', '-M', 101, 'myuser'], has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(['/usr/sbin/lchage', '-M', 101, 'myuser'], hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.password_max_age = 101
       end
     end
@@ -250,35 +290,85 @@ describe Puppet::Type.type(:user).provider(:useradd) do
   describe "#uid=" do
     it "should add -o when allowdupe is enabled and the uid is being modified" do
       resource[:allowdupe] = :true
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-u', 150, '-o', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-u', 150, '-o', 'myuser'], hash_including(custom_environment: {}))
       provider.uid = 150
     end
   end
 
   describe "#expiry=" do
     it "should pass expiry to usermod as MM/DD/YY when on Solaris" do
-      Facter.expects(:value).with(:operatingsystem).returns 'Solaris'
+      expect(Facter).to receive(:value).with(:operatingsystem).and_return('Solaris')
       resource[:expiry] = '2012-10-31'
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-e', '10/31/2012', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-e', '10/31/2012', 'myuser'], hash_including(custom_environment: {}))
       provider.expiry = '2012-10-31'
     end
 
     it "should pass expiry to usermod as YYYY-MM-DD when not on Solaris" do
-      Facter.expects(:value).with(:operatingsystem).returns 'not_solaris'
+      expect(Facter).to receive(:value).with(:operatingsystem).and_return('not_solaris')
       resource[:expiry] = '2012-10-31'
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-e', '2012-10-31', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-e', '2012-10-31', 'myuser'], hash_including(custom_environment: {}))
       provider.expiry = '2012-10-31'
     end
 
     it "should use -e with an empty string when the expiry property is removed" do
       resource[:expiry] = :absent
-      provider.expects(:execute).with(['/usr/sbin/usermod', '-e', '', 'myuser'], has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(['/usr/sbin/usermod', '-e', '', 'myuser'], hash_including(custom_environment: {}))
       provider.expiry = :absent
     end
   end
 
-  describe "#check_allow_dup" do
+  describe "#comment" do
+    before { described_class.has_feature :libuser }
 
+    let(:content) { "myuser:x:x:x:local comment:x:x" }
+
+    it "should return the local comment string when forcelocal is true" do
+      resource[:forcelocal] = true
+      allow(File).to receive(:read).with('/etc/passwd').and_return(content)
+      expect(provider.comment).to eq('local comment')
+    end
+
+    it "should fall back to nameservice comment string when forcelocal is false" do
+      resource[:forcelocal] = false
+      allow(provider).to receive(:get).with(:comment).and_return('remote comment')
+      expect(provider).not_to receive(:localcomment)
+      expect(provider.comment).to eq('remote comment')
+    end
+  end
+
+  describe "#finduser" do
+    before { allow(File).to receive(:read).with('/etc/passwd').and_return(content) }
+
+    let(:content) { "sample_account:sample_password:sample_uid:sample_gid:sample_gecos:sample_directory:sample_shell" }
+    let(:output) do
+      {
+        account: 'sample_account',
+        password: 'sample_password',
+        uid: 'sample_uid',
+        gid: 'sample_gid',
+        gecos: 'sample_gecos',
+        directory: 'sample_directory',
+        shell: 'sample_shell',
+      }
+    end
+
+    [:account, :password, :uid, :gid, :gecos, :directory, :shell].each do |key|
+      it "finds an user by #{key} when asked" do
+        expect(provider.finduser(key, "sample_#{key}")).to eq(output)
+      end
+    end
+
+    it "returns false when specified key/value pair is not found" do
+      expect(provider.finduser(:account, 'invalid_account')).to eq(false)
+    end
+
+    it "reads the user file only once per resource" do
+      expect(File).to receive(:read).with('/etc/passwd').once
+      5.times { provider.finduser(:account, 'sample_account') }
+    end
+  end
+
+  describe "#check_allow_dup" do
     it "should return an array with a flag if dup is allowed" do
       resource[:allowdupe] = :true
       expect(provider.check_allow_dup).to eq(["-o"])
@@ -292,25 +382,25 @@ describe Puppet::Type.type(:user).provider(:useradd) do
 
   describe "#check_system_users" do
     it "should check system users" do
-      described_class.expects(:system_users?).returns true
-      resource.expects(:system?)
+      expect(described_class).to receive(:system_users?).and_return(true)
+      expect(resource).to receive(:system?)
       provider.check_system_users
     end
 
     it "should return an array with a flag if it's a system user" do
-      described_class.expects(:system_users?).returns true
+      expect(described_class).to receive(:system_users?).and_return(true)
       resource[:system] = :true
       expect(provider.check_system_users).to eq(["-r"])
     end
 
     it "should return an empty array if it's not a system user" do
-      described_class.expects(:system_users?).returns true
+      expect(described_class).to receive(:system_users?).and_return(true)
       resource[:system] = :false
       expect(provider.check_system_users).to eq([])
     end
 
     it "should return an empty array if system user is not featured" do
-      described_class.expects(:system_users?).returns false
+      expect(described_class).to receive(:system_users?).and_return(false)
       resource[:system] = :true
       expect(provider.check_system_users).to eq([])
     end
@@ -319,29 +409,29 @@ describe Puppet::Type.type(:user).provider(:useradd) do
   describe "#check_manage_home" do
     it "should return an array with -m flag if home is managed" do
       resource[:managehome] = :true
-      provider.expects(:execute).with(includes('-m'), has_entry(:custom_environment, {}))
+      expect(provider).to receive(:execute).with(include('-m'), hash_including(custom_environment: {}))
       provider.create
     end
 
     it "should return an array with -r flag if home is managed" do
       resource[:managehome] = :true
       resource[:ensure] = :absent
-      provider.stubs(:exists?).returns(true)
-      provider.expects(:execute).with(includes('-r'), has_entry(:custom_environment, {}))
+      allow(provider).to receive(:exists?).and_return(true)
+      expect(provider).to receive(:execute).with(include('-r'), hash_including(custom_environment: {}))
       provider.delete
     end
 
     it "should use -M flag if home is not managed and on Redhat" do
-      Facter.stubs(:value).with(:osfamily).returns("RedHat")
+      allow(Facter).to receive(:value).with(:osfamily).and_return("RedHat")
       resource[:managehome] = :false
-      provider.expects(:execute).with(includes('-M'), kind_of(Hash))
+      expect(provider).to receive(:execute).with(include('-M'), kind_of(Hash))
       provider.create
     end
 
     it "should not use -M flag if home is not managed and not on Redhat" do
-      Facter.stubs(:value).with(:osfamily).returns("not RedHat")
+      allow(Facter).to receive(:value).with(:osfamily).and_return("not RedHat")
       resource[:managehome] = :false
-      provider.expects(:execute).with(Not(includes('-M')), kind_of(Hash))
+      expect(provider).to receive(:execute).with(excluding('-M'), kind_of(Hash))
       provider.create
     end
   end
@@ -355,22 +445,22 @@ describe Puppet::Type.type(:user).provider(:useradd) do
     end
 
     it "should call command with :add" do
-      provider.expects(:command).with(:add)
+      expect(provider).to receive(:command).with(:add)
       provider.addcmd
     end
 
     it "should add properties" do
-      provider.expects(:add_properties).returns(['-foo_add_properties'])
+      expect(provider).to receive(:add_properties).and_return(['-foo_add_properties'])
       expect(provider.addcmd).to include '-foo_add_properties'
     end
 
     it "should check and add if dup allowed" do
-      provider.expects(:check_allow_dup).returns(['-allow_dup_flag'])
+      expect(provider).to receive(:check_allow_dup).and_return(['-allow_dup_flag'])
       expect(provider.addcmd).to include '-allow_dup_flag'
     end
 
     it "should check and add if home is managed" do
-      provider.expects(:check_manage_home).returns(['-manage_home_flag'])
+      expect(provider).to receive(:check_manage_home).and_return(['-manage_home_flag'])
       expect(provider.addcmd).to include '-manage_home_flag'
     end
 
@@ -400,26 +490,26 @@ describe Puppet::Type.type(:user).provider(:useradd) do
     end
 
     it "should return an array with the full command and expiry as MM/DD/YY when on Solaris" do
-      Facter.stubs(:value).with(:operatingsystem).returns 'Solaris'
-      described_class.expects(:system_users?).returns true
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('Solaris')
+      expect(described_class).to receive(:system_users?).and_return(true)
       resource[:expiry] = "2012-08-18"
       expect(provider.addcmd).to eq(['/usr/sbin/useradd', '-e', '08/18/2012', '-G', 'somegroup', '-o', '-m', '-r', 'myuser'])
     end
 
     it "should return an array with the full command and expiry as YYYY-MM-DD when not on Solaris" do
-      Facter.stubs(:value).with(:operatingsystem).returns 'not_solaris'
-      described_class.expects(:system_users?).returns true
+      allow(Facter).to receive(:value).with(:operatingsystem).and_return('not_solaris')
+      expect(described_class).to receive(:system_users?).and_return(true)
       resource[:expiry] = "2012-08-18"
       expect(provider.addcmd).to eq(['/usr/sbin/useradd', '-e', '2012-08-18', '-G', 'somegroup', '-o', '-m', '-r', 'myuser'])
     end
 
     it "should return an array without -e if expiry is undefined full command" do
-      described_class.expects(:system_users?).returns true
+      expect(described_class).to receive(:system_users?).and_return(true)
       expect(provider.addcmd).to eq(["/usr/sbin/useradd", "-G", "somegroup", "-o", "-m", "-r", "myuser"])
     end
 
     it "should pass -e \"\" if the expiry has to be removed" do
-      described_class.expects(:system_users?).returns true
+      expect(described_class).to receive(:system_users?).and_return(true)
       resource[:expiry] = :absent
 
       expect(provider.addcmd).to eq(['/usr/sbin/useradd', '-e', '', '-G', 'somegroup', '-o', '-m', '-r', 'myuser'])
@@ -471,18 +561,18 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       end
 
       it "should return absent if libshadow feature is not present" do
-        Puppet.features.stubs(:libshadow?).returns false
+        allow(Puppet.features).to receive(:libshadow?).and_return(false)
         # Shadow::Passwd.expects(:getspnam).never # if we really don't have libshadow we dont have Shadow::Passwd either
         expect(provider.send(property)).to eq(:absent)
       end
 
       it "should return absent if user cannot be found", :if => Puppet.features.libshadow? do
-        Shadow::Passwd.expects(:getspnam).with('myuser').returns nil
+        expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(nil)
         expect(provider.send(property)).to eq(:absent)
       end
 
       it "should return the correct value if libshadow is present", :if => Puppet.features.libshadow? do
-        Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+        expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
         expect(provider.send(property)).to eq(expected_value)
       end
 
@@ -495,7 +585,7 @@ describe Puppet::Type.type(:user).provider(:useradd) do
         canonical_name = [253, 241].pack('C*').force_encoding(Encoding::EUC_KR)
         provider = described_class.new(:name => '??', :canonical_name => canonical_name)
 
-        Shadow::Passwd.expects(:getspnam).with(canonical_name).returns shadow_entry
+        expect(Shadow::Passwd).to receive(:getspnam).with(canonical_name).and_return(shadow_entry)
         provider.password
       end
     end
@@ -507,23 +597,23 @@ describe Puppet::Type.type(:user).provider(:useradd) do
     end
 
     it "should return absent if libshadow feature is not present" do
-      Puppet.features.stubs(:libshadow?).returns false
+      allow(Puppet.features).to receive(:libshadow?).and_return(false)
       expect(provider.expiry).to eq(:absent)
     end
 
     it "should return absent if user cannot be found", :if => Puppet.features.libshadow? do
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns nil
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(nil)
       expect(provider.expiry).to eq(:absent)
     end
 
     it "should return absent if expiry is -1", :if => Puppet.features.libshadow? do
       shadow_entry.sp_expire = -1
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
       expect(provider.expiry).to eq(:absent)
     end
 
     it "should convert to YYYY-MM-DD", :if => Puppet.features.libshadow? do
-      Shadow::Passwd.expects(:getspnam).with('myuser').returns shadow_entry
+      expect(Shadow::Passwd).to receive(:getspnam).with('myuser').and_return(shadow_entry)
       expect(provider.expiry).to eq('2013-01-01')
     end
   end
@@ -540,7 +630,7 @@ describe Puppet::Type.type(:user).provider(:useradd) do
       # command(:password) is only called inside passcmd if
       # password_min_age or password_max_age is set
       resource[:password_min_age] = 123
-      provider.expects(:command).with(:password)
+      expect(provider).to receive(:command).with(:password)
       provider.passcmd
     end
 
@@ -597,7 +687,7 @@ describe Puppet::Type.type(:user).provider(:useradd) do
     end
 
     it "should raise an error if the shell is not executable" do
-      FileTest.stubs(:executable?).with('LICENSE').returns false
+      allow(FileTest).to receive(:executable?).with('LICENSE').and_return(false)
       resource[:shell] = 'LICENSE'
       expect { provider.check_valid_shell }.to raise_error(Puppet::Error, /Shell LICENSE must be executable/)
     end
@@ -605,26 +695,30 @@ describe Puppet::Type.type(:user).provider(:useradd) do
 
   describe "#delete" do
     before do
-       provider.stubs(:exists?).returns(true)
+       allow(provider).to receive(:exists?).and_return(true)
        resource[:ensure] = :absent
     end
+
     describe "on systems with the libuser and forcelocal=false" do
       before do
          described_class.has_feature :libuser
          resource[:forcelocal] = false
       end
+
       it "should use userdel to delete users" do
-        provider.expects(:execute).with(includes('/usr/sbin/userdel'), has_entry(:custom_environment, {}))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/userdel'), hash_including(custom_environment: {}))
         provider.delete
       end
     end
+
     describe "on systems with the libuser and forcelocal=true" do
       before do
          described_class.has_feature :libuser
          resource[:forcelocal] = true
       end
+
       it "should use luserdel to delete users" do
-        provider.expects(:execute).with(includes('/usr/sbin/luserdel'), has_entry(:custom_environment, has_key('LIBUSER_CONF')))
+        expect(provider).to receive(:execute).with(include('/usr/sbin/luserdel'), hash_including(custom_environment: hash_including('LIBUSER_CONF')))
         provider.delete
       end
     end
